pub struct LoginProfile {
pub name: Option<String>,
pub posix_accounts: Option<Vec<PosixAccount>>,
pub security_keys: Option<Vec<SecurityKey>>,
pub ssh_public_keys: Option<HashMap<String, SshPublicKey>>,
}Expand description
The user profile information used for logging in to a virtual machine on Google Compute Engine.
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
- get login profile users (response)
Fields
name: Option<String>Required. A unique user ID.
posix_accounts: Option<Vec<PosixAccount>>The list of POSIX accounts associated with the user.
security_keys: Option<Vec<SecurityKey>>The registered security key credentials for a user.
ssh_public_keys: Option<HashMap<String, SshPublicKey>>A map from SSH public key fingerprint to the associated key object.