pub struct PosixAccount {
pub account_id: Option<String>,
pub gecos: Option<String>,
pub gid: Option<i64>,
pub home_directory: Option<String>,
pub name: Option<String>,
pub operating_system_type: Option<String>,
pub primary: Option<bool>,
pub shell: Option<String>,
pub system_id: Option<String>,
pub uid: Option<i64>,
pub username: Option<String>,
}Expand description
The POSIX account information associated with a Google account.
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
- projects provision posix account users (response)
Fields
account_id: Option<String>Output only. A POSIX account identifier.
gecos: Option<String>The GECOS (user information) entry for this account.
gid: Option<i64>The default group ID.
home_directory: Option<String>The path to the home directory for this account.
name: Option<String>Output only. The canonical resource name.
operating_system_type: Option<String>The operating system type where this account applies.
primary: Option<bool>Only one POSIX account can be marked as primary.
shell: Option<String>The path to the logic shell for this account.
system_id: Option<String>System identifier for which account the username or uid applies to. By default, the empty value is used.
uid: Option<i64>The user ID.
username: Option<String>The username of the POSIX account.