pub struct SecurityKey {
pub device_nickname: Option<String>,
pub private_key: Option<String>,
pub public_key: Option<String>,
pub universal_two_factor: Option<UniversalTwoFactor>,
pub web_authn: Option<WebAuthn>,
}Expand description
The credential information for a Google registered security key.
This type is not used in any activity, and only used as part of another schema.
Fields
device_nickname: Option<String>The security key nickname explicitly set by the user.
private_key: Option<String>Hardware-backed private key text in SSH format.
public_key: Option<String>Public key text in SSH format, defined by RFC4253 section 6.6.
universal_two_factor: Option<UniversalTwoFactor>The U2F protocol type.
web_authn: Option<WebAuthn>The Web Authentication protocol type.