pub struct SignSshPublicKeyResponse {
pub signed_ssh_public_key: Option<String>,
}Expand description
There is no detailed description.
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
- projects locations sign ssh public key users (response)
- projects zones sign ssh public key users (response)
Fields
signed_ssh_public_key: Option<String>The signed SSH public key to use in the SSH handshake.