pub struct WebAuthn {
pub rp_id: Option<String>,
}Expand description
Security key information specific to the Web Authentication protocol.
This type is not used in any activity, and only used as part of another schema.
Fields
rp_id: Option<String>Relying party ID for Web Authentication.